@@ -23,7 +23,6 @@
 #include <stdlib.h>
 
 #include <govirt/govirt.h>
-#include "govirt/glib-compat.h"
 
 static const char *
 genum_get_nick (GType enum_type, gint value)
@@ -128,8 +127,6 @@ int main(int argc, char **argv)
     gchar *ticket = NULL;
     GByteArray *ca_cert = NULL;
 
-    g_type_init();
-
     if (argc != 3) {
         g_print("Usage: %s URI VM-NAME\n", argv[0]);
         exit(1);
