@@ -195,8 +195,6 @@ RestXmlNode *ovirt_proxy_get_collection_xml(OvirtProxy *proxy,
 typedef struct {
     OvirtProxy *proxy;
     GTask *task;
-    GCancellable *cancellable;
-    gulong cancellable_cb_id;
     OvirtProxyCallAsyncCb call_async_cb;
     gpointer call_user_data;
     GDestroyNotify destroy_call_data;
@@ -211,29 +209,9 @@ static void ovirt_proxy_call_async_data_free(OvirtProxyCallAsyncData *data)
     g_clear_object(&data->proxy);
     g_clear_object(&data->task);
 
-    if ((data->cancellable != NULL) && (data->cancellable_cb_id != 0)) {
-        if (g_cancellable_is_cancelled(data->cancellable)) {
-            /* Cancellable has already been cancelled, we don't need to use
-             * g_cancellable_disconnect() to disconnect the signal handler
-             * as we know the 'cancelled' signal is no longer going to be emitted
-             */
-            g_signal_handler_disconnect(data->cancellable, data->cancellable_cb_id);
-        } else {
-            g_cancellable_disconnect(data->cancellable, data->cancellable_cb_id);
-        }
-    }
-    g_clear_object(&data->cancellable);
     g_slice_free(OvirtProxyCallAsyncData, data);
 }
 
-static void
-call_async_cancelled_cb (G_GNUC_UNUSED GCancellable *cancellable,
-                         RestProxyCall *call)
-{
-    rest_proxy_call_cancel(call);
-}
-
-
 static void rest_call_async_set_error(RestProxyCall *call, GTask *task, const GError *error)
 {
     GError *local_error = NULL;
@@ -252,26 +230,26 @@ static void rest_call_async_set_error(RestProxyCall *call, GTask *task, const GE
 }
 
 static void
-call_async_cb(RestProxyCall *call, const GError *error,
-              G_GNUC_UNUSED GObject *weak_object,
+call_async_cb(GObject *source_obj,
+              GAsyncResult *result,
               gpointer user_data)
 {
+    RestProxyCall *call = REST_PROXY_CALL(source_obj);
+    GError *error = NULL;
     OvirtProxyCallAsyncData *data = user_data;
     GTask *task = data->task;
     gboolean callback_result = TRUE;
 
+    rest_proxy_call_invoke_finish(call, result, &error);
     if (error != NULL) {
-        rest_call_async_set_error(call, task, error);
         goto exit;
     }
 
     if (data->call_async_cb != NULL) {
-        GError *call_error = NULL;
         callback_result = data->call_async_cb(data->proxy, call,
                                               data->call_user_data,
-                                              &call_error);
-        if (call_error != NULL) {
-            rest_call_async_set_error(call, task, call_error);
+                                              &error);
+        if (error != NULL) {
             goto exit;
         }
     }
@@ -279,6 +257,9 @@ call_async_cb(RestProxyCall *call, const GError *error,
     g_task_return_boolean(task, callback_result);
 
 exit:
+    if (error != NULL) {
+        rest_call_async_set_error(call, task, error);
+    }
     ovirt_proxy_call_async_data_free(data);
 }
 
@@ -291,7 +272,6 @@ void ovirt_rest_call_async(OvirtRestCall *call,
                            GDestroyNotify destroy_func)
 {
     OvirtProxy *proxy;
-    GError *error = NULL;
     OvirtProxyCallAsyncData *data;
 
     g_return_if_fail((cancellable == NULL) || G_IS_CANCELLABLE(cancellable));
@@ -304,19 +284,8 @@ void ovirt_rest_call_async(OvirtRestCall *call,
     data->call_async_cb = callback;
     data->call_user_data = user_data;
     data->destroy_call_data = destroy_func;
-    if (cancellable != NULL) {
-        data->cancellable = g_object_ref(cancellable);
-        data->cancellable_cb_id = g_cancellable_connect(cancellable,
-                                                        G_CALLBACK (call_async_cancelled_cb),
-                                                        call, NULL);
-    }
 
-    if (!rest_proxy_call_async(REST_PROXY_CALL(call), call_async_cb, NULL,
-                               data, &error)) {
-        g_warning("Error while getting collection XML");
-        g_task_return_error(task, error);
-        ovirt_proxy_call_async_data_free(data);
-    }
+    rest_proxy_call_invoke_async(REST_PROXY_CALL (call), cancellable, call_async_cb, data);
 }
 
 
