@@ -41,6 +41,8 @@ typedef enum {
     OVIRT_STORAGE_DOMAIN_FORMAT_VERSION_V1,
     OVIRT_STORAGE_DOMAIN_FORMAT_VERSION_V2,
     OVIRT_STORAGE_DOMAIN_FORMAT_VERSION_V3,
+    OVIRT_STORAGE_DOMAIN_FORMAT_VERSION_V4,
+    OVIRT_STORAGE_DOMAIN_FORMAT_VERSION_V5,
 } OvirtStorageDomainFormatVersion;
 
 typedef enum {
@@ -60,7 +62,18 @@ typedef enum {
     OVIRT_STORAGE_DOMAIN_TYPE_IMAGE,
 } OvirtStorageDomainType;
 
-typedef struct _OvirtStorageDomain OvirtStorageDomain;
+typedef enum {
+    OVIRT_STORAGE_DOMAIN_STORAGE_TYPE_CINDER,
+    OVIRT_STORAGE_DOMAIN_STORAGE_TYPE_FCP,
+    OVIRT_STORAGE_DOMAIN_STORAGE_TYPE_GLANCE,
+    OVIRT_STORAGE_DOMAIN_STORAGE_TYPE_GLUSTERFS,
+    OVIRT_STORAGE_DOMAIN_STORAGE_TYPE_ISCSI,
+    OVIRT_STORAGE_DOMAIN_STORAGE_TYPE_LOCALFS,
+    OVIRT_STORAGE_DOMAIN_STORAGE_TYPE_MANAGED_BLOCK_STORAGE,
+    OVIRT_STORAGE_DOMAIN_STORAGE_TYPE_NFS,
+    OVIRT_STORAGE_DOMAIN_STORAGE_TYPE_POSIXFS,
+} OvirtStorageDomainStorageType;
+
 typedef struct _OvirtStorageDomainPrivate OvirtStorageDomainPrivate;
 typedef struct _OvirtStorageDomainClass OvirtStorageDomainClass;
 
@@ -85,6 +98,7 @@ GType ovirt_storage_domain_get_type(void);
 OvirtStorageDomain *ovirt_storage_domain_new(void);
 
 OvirtCollection *ovirt_storage_domain_get_files(OvirtStorageDomain *domain);
+OvirtCollection *ovirt_storage_domain_get_disks(OvirtStorageDomain *domain);
 
 G_END_DECLS
 
